Noncommutative utilities for Geometric Algebra
==============================================

.. module:: sympy.galgebra.ncutil

Function Reference
------------------

.. autofunction:: bilinear_function

.. autofunction:: bilinear_product

.. autofunction:: coef_function

.. autofunction:: linear_derivation

.. autofunction:: linear_expand

.. autofunction:: linear_function

.. autofunction:: linear_projection

.. autofunction:: multilinear_derivation

.. autofunction:: multilinear_function

.. autofunction:: multilinear_product

.. autofunction:: non_scalar_projection

.. autofunction:: product_derivation
